@@ -1,35 +1,43 @@
 # Copyright 2019-2021 Siemens AG
 # SPDX-License-Identifier: MIT
 
-import re
 import logging
-import requests
+import re
 from datetime import date, timedelta
-
 from typing import Dict, List
-from fossology.obj import (
-    Agents,
-    Upload,
-    User,
-    File,
-    TokenScope,
-    SearchTypes,
-    get_options,
-)
-from fossology.folders import Folders
-from fossology.uploads import Uploads
-from fossology.jobs import Jobs
-from fossology.report import Report
+
+import requests
+
 from fossology.exceptions import (
     AuthenticationError,
     AuthorizationError,
     FossologyApiError,
+    FossologyUnsupported,
 )
+from fossology.folders import Folders
+from fossology.groups import Groups
+from fossology.jobs import Jobs
+from fossology.license import LicenseEndpoint
+from fossology.obj import (
+    Agents,
+    File,
+    SearchTypes,
+    TokenScope,
+    Upload,
+    User,
+    get_options,
+)
+from fossology.report import Report
+from fossology.uploads import Uploads
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 
 
+def versiontuple(v):
+    return tuple(map(int, (v.split("."))))
+
+
 def search_headers(
     searchType: SearchTypes = SearchTypes.ALLFILES,
     upload: Upload = None,
@@ -118,7 +126,7 @@ def fossology_token(
         exit(f"Server {url} does not seem to be running or is unreachable: {error}")
 
 
-class Fossology(Folders, Uploads, Jobs, Report):
+class Fossology(Folders, Groups, LicenseEndpoint, Uploads, Jobs, Report):
 
     """Main Fossology API class
 
@@ -345,6 +353,10 @@ class Fossology(Folders, Uploads, Jobs, Report):
         :raises FossologyApiError: if the REST call failed
         :raises AuthorizationError: if the user can't access the group
         """
+        if versiontuple(self.version) <= versiontuple("1.0.16"):
+            description = f"Endpoint /filesearch is not supported by your Fossology API version {self.version}"
+            raise FossologyUnsupported(description)
+
         headers = {}
         if group:
             headers["groupName"] = group
