@@ -2,12 +2,13 @@
 # SPDX-License-Identifier: MIT
 
 import json
-import time
 import logging
+import time
+
+from tenacity import TryAgain, retry, retry_if_exception_type, stop_after_attempt
 
-from tenacity import retry, retry_if_exception_type, stop_after_attempt, TryAgain
-from fossology.obj import Upload, Summary, Licenses, get_options
 from fossology.exceptions import AuthorizationError, FossologyApiError
+from fossology.obj import Licenses, Summary, Upload, get_options
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -83,6 +84,7 @@ class Uploads:
         file=None,
         vcs=None,
         url=None,
+        server=None,
         description=None,
         access_level=None,
         ignore_scm=False,
@@ -141,10 +143,25 @@ class Uploads:
                 access_level=AccessLevel.PUBLIC,
             )
 
+        :Example for a SERVER upload:
+
+        >>> server = {
+                "path": "/tmp/fossology-python",
+                "name": "fossology-python",
+            }
+        >>> server_upload = foss.upload_file(
+                foss.rootFolder,
+                server=server,
+                description="Upload from SERVER",
+                access_level=AccessLevel.PUBLIC,
+            )
+
+
         :param folder: the upload Fossology folder
         :param file: the local path of the file to be uploaded
         :param vcs: the VCS specification to upload from an online repository
         :param url: the URL specification to upload from a url
+        :param server: the SERVER specification to upload from fossology server
         :param description: description of the upload (default: None)
         :param access_level: access permissions of the upload (default: protected)
         :param ignore_scm: ignore SCM files (Git, SVN, TFS) (default: True)
@@ -154,6 +171,7 @@ class Uploads:
         :type file: string
         :type vcs: dict()
         :type url: dict()
+        :type server: dict()
         :type description: string
         :type access_level: AccessLevel
         :type ignore_scm: boolean
@@ -181,13 +199,16 @@ class Uploads:
                 response = self.session.post(
                     f"{self.api}/uploads", files=files, headers=headers
                 )
-        elif vcs or url:
+        elif vcs or url or server:
             if vcs:
                 headers["uploadType"] = "vcs"
                 data = json.dumps(vcs)
-            else:
+            elif url:
                 headers["uploadType"] = "url"
                 data = json.dumps(url)
+            elif server:
+                headers["uploadType"] = "server"
+                data = json.dumps(server)
             headers["Content-Type"] = "application/json"
             response = self.session.post(
                 f"{self.api}/uploads", data=data, headers=headers
@@ -202,16 +223,24 @@ class Uploads:
             source = f"{file}"
         elif vcs:
             source = vcs.get("vcsName")
-        else:
+        elif url:
             source = url.get("name")
+        elif server:
+            source = server.get("name")
 
         if response.status_code == 201:
             try:
                 upload = self.detail_upload(response.json()["message"], wait_time)
-                logger.info(
-                    f"Upload {upload.uploadname} ({upload.hash.size}) "
-                    f"has been uploaded on {upload.uploaddate}"
-                )
+                if upload.filesize:
+                    logger.info(
+                        f"Upload {upload.uploadname} ({upload.filesize}) "
+                        f"has been uploaded on {upload.uploaddate}"
+                    )
+                else:
+                    logger.info(
+                        f"Upload {upload.uploadname} ({upload.hash.size}) "
+                        f"has been uploaded on {upload.uploaddate}"
+                    )
                 return upload
             except TryAgain:
                 description = f"Upload of {source} failed"
@@ -223,6 +252,15 @@ class Uploads:
             )
             raise AuthorizationError(description, response)
 
+        elif server and response.status_code == 500:
+            description = (
+                f"Upload {description} could not be performed; "
+                f"did you add a prefix for '{server['path']}' in Fossology config "
+                f"variable 'Admin->Customize->Whitelist for serverupload'? "
+                f"Has fossy user read access to {server['path']}?"
+            )
+            raise FossologyApiError(description, response)
+
         else:
             description = f"Upload {description} could not be performed"
             raise FossologyApiError(description, response)
@@ -365,7 +403,13 @@ class Uploads:
             raise FossologyApiError(description, response)
 
     def list_uploads(
-        self, folder=None, group=None, recursive=True, page_size=20, page=1
+        self,
+        folder=None,
+        group=None,
+        recursive=True,
+        page_size=100,
+        page=1,
+        all_pages=False,
     ):
         """Get all uploads available to the registered user
 
@@ -374,20 +418,22 @@ class Uploads:
         :param folder: only list uploads from the given folder
         :param group: list uploads from a specific group (not only your own uploads) (default: None)
         :param recursive: wether to list uploads from children folders or not (default: True)
-        :param page_size: limit the number of uploads per page (default: 20)
+        :param page_size: limit the number of uploads per page (default: 100)
         :param page: the number of the page to fetch uploads from (default: 1)
+        :param all_pages: get all uploads (default: False)
         :type folder: Folder
         :type group: string
         :type recursive: boolean
         :type page_size: int
         :type page: int
-        :return: a list of uploads
-        :rtype: list of Upload
+        :type all_pages: boolean
+        :return: a tuple containing the list of uploads and the total number of pages
+        :rtype: Tuple(list of Upload, int)
         :raises FossologyApiError: if the REST call failed
         :raises AuthorizationError: if the user can't access the group
         """
         params = {}
-        headers = {"limit": str(page_size), "page": str(page)}
+        headers = {"limit": str(page_size)}
         if group:
             headers["groupName"] = group
         if folder:
@@ -395,28 +441,37 @@ class Uploads:
         if not recursive:
             params["recursive"] = "false"
 
-        response = self.session.get(
-            f"{self.api}/uploads", headers=headers, params=params
-        )
-
-        if response.status_code == 200:
-            uploads_list = list()
-            for upload in response.json():
-                uploads_list.append(Upload.from_json(upload))
-            logger.info(
-                f"Retrieved page {page} of uploads, {response.headers.get('X-TOTAL-PAGES', 'Unknown')} pages are in total available"
-            )
-            return uploads_list
-
-        elif response.status_code == 403:
-            description = (
-                f"Retrieving list of uploads {get_options(group, folder)}not authorized"
-            )
-            raise AuthorizationError(description, response)
-
+        uploads_list = list()
+        if all_pages:
+            # will be reset after the total number of pages has been retrieved from the API
+            x_total_pages = 2
         else:
-            description = "Unable to retrieve the list of uploads"
-            raise FossologyApiError(description, response)
+            x_total_pages = page
+        while page <= x_total_pages:
+            headers["page"] = str(page)
+            response = self.session.get(
+                f"{self.api}/uploads", headers=headers, params=params
+            )
+            if response.status_code == 200:
+                for upload in response.json():
+                    uploads_list.append(Upload.from_json(upload))
+                x_total_pages = int(response.headers.get("X-TOTAL-PAGES", 0))
+                if not all_pages or x_total_pages == 0:
+                    logger.info(
+                        f"Retrieved page {page} of uploads, {x_total_pages} pages are in total available"
+                    )
+                    return uploads_list, x_total_pages
+                page += 1
+
+            elif response.status_code == 403:
+                description = f"Retrieving list of uploads {get_options(group, folder)}not authorized"
+                raise AuthorizationError(description, response)
+
+            else:
+                description = f"Unable to retrieve the list of uploads from page {page}"
+                raise FossologyApiError(description, response)
+        logger.info(f"Retrieved all {x_total_pages} of uploads")
+        return uploads_list, x_total_pages
 
     def move_upload(self, upload, folder, group=None):
         """Move an upload to another folder
